==> dl.php?src=linea21_1_3.zip: linea21/publication/menurub.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage publication
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')) {
    include_once("../lib/lib_common.php");
    ReloadIndex('admin');
} 
////////////

//////////// Check Droits utilisateur ////////////
if (!HaveRight('publication')) ReloadIndex('admin');
////////////

$rub_link_add=$rub_link."&amp;todo=add";
$rub_link_list=$rub_link."&amp;todo=list";
$rub_link_mod=$rub_link."&amp;todo=mod";
$rub_link_det=$rub_link."&amp;todo=det";

$search="search.php?rub=".$rub;
if($todo=='add') $title=_t('publication','add');
if($todo=='list') $title=_t('publication','list');
if($todo=='mod') $title=_t('publication','mod');
if($todo=='sup') $title=_t('publication','sup');
if($todo=='det') $title=_t('publication','det');
?>
<div id="itemenu">
<h1><?php echo $title; ?></h1>
<div class="contentlink">
				<?php 
				if(IsSuperAdmin()) {
				?>
				<a href="<?php echo $rub_link_add; ?>" id="content_link_add"  title="<? echo _t('publication','add');?>"><? echo _t('publication','add');?></a> 
				| 
				<?php } ?>
				<a href="<?php echo $rub_link_list; ?>" id="content_link_list"  title="<? echo _t('publication','list');?>"><? echo _t('publication','list');?></a>
				| 
				<a href="<?php echo $search; ?>" id="content_link_search"  title="<? echo _t('menu','search');?>"><? echo _t('menu','search');?></a>
</div>
</div>

==> dl.php?src=linea21_1_4.zip: linea21/publication/menurub.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage publication
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!HaveRight('publication')) ReloadIndex('admin');
////////////

$rub_link_add=$rub_link."&amp;todo=add";
$rub_link_list=$rub_link."&amp;todo=list";
$rub_link_mod=$rub_link."&amp;todo=mod";
$rub_link_det=$rub_link."&amp;todo=det";

$search="search.php?rub=".$rub;
if($todo=='add') $title=_t('publication','add');
if($todo=='list') $title=_t('publication','list');
if($todo=='mod') $title=_t('publication','mod');
if($todo=='sup') $title=_t('publication','sup');
if($todo=='det') $title=_t('publication','det');
?>
<div id="itemenu">
<h1><?php echo $title; ?></h1>
<div class="contentlink"><?php 
if(IsSuperAdmin()) {
  ?> <a href="<?php echo $rub_link_add; ?>" id="content_link_add"
	title="<?php echo _t('publication','add');?>"><?php echo _t('publication','add');?></a>
| <?php } ?> <a href="<?php echo $rub_link_list; ?>"
	id="content_link_list" title="<?php echo _t('publication','list');?>"><?php echo _t('publication','list');?></a>
| <a href="<?php echo $search; ?>" id="content_link_search"
	title="<?php echo _t('menu','search');?>"><?php echo _t('menu','search');?></a>
</div>
</div>
